summaryrefslogtreecommitdiffstats
path: root/src/sqlite3gen.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/sqlite3gen.cpp')
-rw-r--r--src/sqlite3gen.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/sqlite3gen.cpp b/src/sqlite3gen.cpp
index 6bc8789..8996014 100644
--- a/src/sqlite3gen.cpp
+++ b/src/sqlite3gen.cpp
@@ -491,8 +491,8 @@ static int step(sqlite3 *db, SqlStmt &s,bool getRowId=FALSE, bool select=FALSE)
sqlite3_clear_bindings(s.stmt);
return -1;
}
- if (getRowId && select) rowid = sqlite3_column_int(s.stmt, 0); // works on selects, doesnt on inserts
- if (getRowId && !select) rowid = sqlite3_last_insert_rowid(db); //works on inserts, doesnt on selects
+ if (getRowId && select) rowid = sqlite3_column_int(s.stmt, 0); // works on selects, doesn't on inserts
+ if (getRowId && !select) rowid = sqlite3_last_insert_rowid(db); //works on inserts, doesn't on selects
sqlite3_reset(s.stmt);
sqlite3_clear_bindings(s.stmt); // XXX When should this really be called
return rowid;